mirror of
https://github.com/encounter/rust-sdl2.git
synced 2026-07-10 21:18:41 -07:00
20 lines
5.0 KiB
HTML
20 lines
5.0 KiB
HTML
|
|
<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="API documentation for the Rust `SDL_CreateThreadWithStackSize` fn in crate `sdl2_sys`."><meta name="keywords" content="rust, rustlang, rust-lang, SDL_CreateThreadWithStackSize"><title>sdl2_sys::SDL_CreateThreadWithStackSize - Rust</title><link rel="stylesheet" type="text/css" href="../normalize.css"><link rel="stylesheet" type="text/css" href="../rustdoc.css" id="mainThemeStyle"><link rel="stylesheet" type="text/css" href="../dark.css"><link rel="stylesheet" type="text/css" href="../light.css" id="themeStyle"><script src="../storage.js"></script><noscript><link rel="stylesheet" href="../noscript.css"></noscript><link rel="shortcut icon" href="../favicon.ico"><style type="text/css">#crate-search{background-image:url("../down-arrow.svg");}</style></head><body class="rustdoc fn"><!--[if lte IE 8]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><nav class="sidebar"><div class="sidebar-menu">☰</div><a href='../sdl2_sys/index.html'><div class='logo-container'><img src='../rust-logo.png' alt='logo'></div></a><div class="sidebar-elems"><p class='location'><a href='index.html'>sdl2_sys</a></p><script>window.sidebarCurrent = {name: 'SDL_CreateThreadWithStackSize', ty: 'fn', relpath: ''};</script><script defer src="sidebar-items.js"></script></div></nav><div class="theme-picker"><button id="theme-picker" aria-label="Pick another theme!"><img src="../brush.svg" width="18" alt="Pick another theme!"></button><div id="theme-choices"></div></div><script src="../theme.js"></script><nav class="sub"><form class="search-form"><div class="search-container"><div><select id="crate-search"><option value="All crates">All crates</option></select><input class="search-input" name="search" disabled autocomplete="off" spellcheck="false" placeholder="Click or press ‘S’ to search, ‘?’ for more options…" type="search"></div><a id="settings-menu" href="../settings.html"><img src="../wheel.svg" width="18" alt="Change settings"></a></div></form></nav><section id="main" class="content"><h1 class='fqn'><span class='out-of-band'><span id='render-detail'><a id="toggle-all-docs" href="javascript:void(0)" title="collapse all docs">[<span class='inner'>−</span>]</a></span><a class='srclink' href='../src/sdl2_sys/Users/travis/build/Rust-SDL2/rust-sdl2/target/debug/build/sdl2-sys-f32779682524d647/out/sdl_bindings.rs.html#2101-2106' title='goto source code'>[src]</a></span><span class='in-band'>Function <a href='index.html'>sdl2_sys</a>::<wbr><a class="fn" href=''>SDL_CreateThreadWithStackSize</a></span></h1><pre class='rust fn'>pub unsafe extern "C" fn SDL_CreateThreadWithStackSize(<br> fn_: <a class="type" href="../sdl2_sys/type.SDL_ThreadFunction.html" title="type sdl2_sys::SDL_ThreadFunction">SDL_ThreadFunction</a>, <br> name: *const <a class="type" href="../libc/unix/bsd/apple/type.c_char.html" title="type libc::unix::bsd::apple::c_char">c_char</a>, <br> stacksize: <a class="type" href="../sdl2_sys/type.size_t.html" title="type sdl2_sys::size_t">size_t</a>, <br> data: *mut <a class="enum" href="https://doc.rust-lang.org/nightly/core/ffi/enum.c_void.html" title="enum core::ffi::c_void">c_void</a><br>) -> *mut <a class="struct" href="../sdl2_sys/struct.SDL_Thread.html" title="struct sdl2_sys::SDL_Thread">SDL_Thread</a></pre><div class='docblock'><p>Create a thread.</p>
|
|||
|
|
<p>Thread naming is a little complicated: Most systems have very small
|
|||
|
|
limits for the string length (Haiku has 32 bytes, Linux currently has 16,
|
|||
|
|
Visual C++ 6.0 has nine!), and possibly other arbitrary rules. You'll
|
|||
|
|
have to see what happens with your system's debugger. The name should be
|
|||
|
|
UTF-8 (but using the naming limits of C identifiers is a better bet).
|
|||
|
|
There are no requirements for thread naming conventions, so long as the
|
|||
|
|
string is null-terminated UTF-8, but these guidelines are helpful in
|
|||
|
|
choosing a name:</p>
|
|||
|
|
<p>http://stackoverflow.com/questions/149932/naming-conventions-for-threads</p>
|
|||
|
|
<p>If a system imposes requirements, SDL will try to munge the string for
|
|||
|
|
it (truncate, etc), but the original string contents will be available
|
|||
|
|
from SDL_GetThreadName().</p>
|
|||
|
|
<p>The size (in bytes) of the new stack can be specified. Zero means "use
|
|||
|
|
the system default" which might be wildly different between platforms
|
|||
|
|
(x86 Linux generally defaults to eight megabytes, an embedded device
|
|||
|
|
might be a few kilobytes instead).</p>
|
|||
|
|
<p>In SDL 2.1, stacksize will be folded into the original SDL_CreateThread
|
|||
|
|
function.</p>
|
|||
|
|
</div></section><section id="search" class="content hidden"></section><section class="footer"></section><script>window.rootPath = "../";window.currentCrate = "sdl2_sys";</script><script src="../aliases.js"></script><script src="../main.js"></script><script defer src="../search-index.js"></script></body></html>
|