mirror of
https://github.com/encounter/rust-sdl2.git
synced 2026-07-10 21:18:41 -07:00
51 lines
25 KiB
HTML
51 lines
25 KiB
HTML
|
|
<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="API documentation for the Rust `SDL_HapticCustom` struct in crate `sdl2_sys`."><meta name="keywords" content="rust, rustlang, rust-lang, SDL_HapticCustom"><title>sdl2_sys::SDL_HapticCustom - Rust</title><link rel="stylesheet" type="text/css" href="../normalize.css"><link rel="stylesheet" type="text/css" href="../rustdoc.css" id="mainThemeStyle"><link rel="stylesheet" type="text/css" href="../dark.css"><link rel="stylesheet" type="text/css" href="../light.css" id="themeStyle"><script src="../storage.js"></script><noscript><link rel="stylesheet" href="../noscript.css"></noscript><link rel="shortcut icon" href="../favicon.ico"><style type="text/css">#crate-search{background-image:url("../down-arrow.svg");}</style></head><body class="rustdoc struct"><!--[if lte IE 8]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><nav class="sidebar"><div class="sidebar-menu">☰</div><a href='../sdl2_sys/index.html'><div class='logo-container'><img src='../rust-logo.png' alt='logo'></div></a><p class='location'>Struct SDL_HapticCustom</p><div class="sidebar-elems"><div class="block items"><a class="sidebar-title" href="#fields">Fields</a><div class="sidebar-links"><a href="#structfield.type_">type_</a><a href="#structfield.direction">direction</a><a href="#structfield.length">length</a><a href="#structfield.delay">delay</a><a href="#structfield.button">button</a><a href="#structfield.interval">interval</a><a href="#structfield.channels">channels</a><a href="#structfield.period">period</a><a href="#structfield.samples">samples</a><a href="#structfield.data">data</a><a href="#structfield.attack_length">attack_length</a><a href="#structfield.attack_level">attack_level</a><a href="#structfield.fade_length">fade_length</a><a href="#structfield.fade_level">fade_level</a></div><a class="sidebar-title" href="#implementations">Trait Implementations</a><div class="sidebar-links"><a href="#impl-Clone">Clone</a><a href="#impl-Copy">Copy</a></div><a class="sidebar-title" href="#synthetic-implementations">Auto Trait Implementations</a><div class="sidebar-links"><a href="#impl-Send">!Send</a><a href="#impl-Sync">!Sync</a><a href="#impl-Unpin">Unpin</a></div><a class="sidebar-title" href="#blanket-implementations">Blanket Implementations</a><div class="sidebar-links"><a href="#impl-Any">Any</a><a href="#impl-Borrow%3CT%3E">Borrow<T></a><a href="#impl-BorrowMut%3CT%3E">BorrowMut<T></a><a href="#impl-From%3CT%3E">From<T></a><a href="#impl-Into%3CU%3E">Into<U></a><a href="#impl-TryFrom%3CU%3E">TryFrom<U></a><a href="#impl-TryInto%3CU%3E">TryInto<U></a></div></div><p class='location'><a href='index.html'>sdl2_sys</a></p><script>window.sidebarCurrent = {name: 'SDL_HapticCustom', ty: 'struct', relpath: ''};</script><script defer src="sidebar-items.js"></script></div></nav><div class="theme-picker"><button id="theme-picker" aria-label="Pick another theme!"><img src="../brush.svg" width="18" alt="Pick another theme!"></button><div id="theme-choices"></div></div><script src="../theme.js"></script><nav class="sub"><form class="search-form"><div class="search-container"><div><select id="crate-search"><option value="All crates">All crates</option></select><input class="search-input" name="search" disabled autocomplete="off" spellcheck="false" placeholder="Click or press ‘S’ to search, ‘?’ for more options…" type="search"></div><a id="settings-menu" href="../settings.html"><img src="../wheel.svg" width="18" alt="Change settings"></a></div></form></nav><section id="main" class="content"><h1 class='fqn'><span class='out-of-band'><span id='render-detail'><a id="toggle-all-docs" href="javascript:void(0)" title="collapse all docs">[<span class='inner'>−</span>]</a></span><a class='srclink' href='../src/sdl2_sys/Users/travis/build/Rust-SDL2/rust-sdl2/ta
|
|||
|
|
pub type_: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
pub direction: <a class="struct" href="../sdl2_sys/struct.SDL_HapticDirection.html" title="struct sdl2_sys::SDL_HapticDirection">SDL_HapticDirection</a>,
|
|||
|
|
pub length: <a class="type" href="../sdl2_sys/type.Uint32.html" title="type sdl2_sys::Uint32">Uint32</a>,
|
|||
|
|
pub delay: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
pub button: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
pub interval: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
pub channels: <a class="type" href="../sdl2_sys/type.Uint8.html" title="type sdl2_sys::Uint8">Uint8</a>,
|
|||
|
|
pub period: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
pub samples: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
pub data: *mut <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
pub attack_length: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
pub attack_level: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
pub fade_length: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
pub fade_level: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a>,
|
|||
|
|
}</pre></div><div class='docblock'><p>\brief A structure containing a template for the ::SDL_HAPTIC_CUSTOM effect.</p>
|
|||
|
|
<p>This struct is exclusively for the ::SDL_HAPTIC_CUSTOM effect.</p>
|
|||
|
|
<p>A custom force feedback effect is much like a periodic effect, where the
|
|||
|
|
application can define its exact shape. You will have to allocate the
|
|||
|
|
data yourself. Data should consist of channels * samples Uint16 samples.</p>
|
|||
|
|
<p>If channels is one, the effect is rotated using the defined direction.
|
|||
|
|
Otherwise it uses the samples in data for the different axes.</p>
|
|||
|
|
<p>\sa SDL_HAPTIC_CUSTOM
|
|||
|
|
\sa SDL_HapticEffect</p>
|
|||
|
|
</div><h2 id='fields' class='fields small-section-header'>
|
|||
|
|
Fields<a href='#fields' class='anchor'></a></h2><span id="structfield.type_" class="structfield small-section-header"><a href="#structfield.type_" class="anchor field"></a><code id="type_.v">type_: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< ::SDL_HAPTIC_CUSTOM</p>
|
|||
|
|
</div><span id="structfield.direction" class="structfield small-section-header"><a href="#structfield.direction" class="anchor field"></a><code id="direction.v">direction: <a class="struct" href="../sdl2_sys/struct.SDL_HapticDirection.html" title="struct sdl2_sys::SDL_HapticDirection">SDL_HapticDirection</a></code></span><div class='docblock'><p>< Direction of the effect.</p>
|
|||
|
|
</div><span id="structfield.length" class="structfield small-section-header"><a href="#structfield.length" class="anchor field"></a><code id="length.v">length: <a class="type" href="../sdl2_sys/type.Uint32.html" title="type sdl2_sys::Uint32">Uint32</a></code></span><div class='docblock'><p>< Duration of the effect.</p>
|
|||
|
|
</div><span id="structfield.delay" class="structfield small-section-header"><a href="#structfield.delay" class="anchor field"></a><code id="delay.v">delay: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< Delay before starting the effect.</p>
|
|||
|
|
</div><span id="structfield.button" class="structfield small-section-header"><a href="#structfield.button" class="anchor field"></a><code id="button.v">button: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< Button that triggers the effect.</p>
|
|||
|
|
</div><span id="structfield.interval" class="structfield small-section-header"><a href="#structfield.interval" class="anchor field"></a><code id="interval.v">interval: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< How soon it can be triggered again after button.</p>
|
|||
|
|
</div><span id="structfield.channels" class="structfield small-section-header"><a href="#structfield.channels" class="anchor field"></a><code id="channels.v">channels: <a class="type" href="../sdl2_sys/type.Uint8.html" title="type sdl2_sys::Uint8">Uint8</a></code></span><div class='docblock'><p>< Axes to use, minimum of one.</p>
|
|||
|
|
</div><span id="structfield.period" class="structfield small-section-header"><a href="#structfield.period" class="anchor field"></a><code id="period.v">period: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< Sample periods.</p>
|
|||
|
|
</div><span id="structfield.samples" class="structfield small-section-header"><a href="#structfield.samples" class="anchor field"></a><code id="samples.v">samples: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< Amount of samples.</p>
|
|||
|
|
</div><span id="structfield.data" class="structfield small-section-header"><a href="#structfield.data" class="anchor field"></a><code id="data.v">data: *mut <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< Should contain channels*samples items.</p>
|
|||
|
|
</div><span id="structfield.attack_length" class="structfield small-section-header"><a href="#structfield.attack_length" class="anchor field"></a><code id="attack_length.v">attack_length: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< Duration of the attack.</p>
|
|||
|
|
</div><span id="structfield.attack_level" class="structfield small-section-header"><a href="#structfield.attack_level" class="anchor field"></a><code id="attack_level.v">attack_level: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< Level at the start of the attack.</p>
|
|||
|
|
</div><span id="structfield.fade_length" class="structfield small-section-header"><a href="#structfield.fade_length" class="anchor field"></a><code id="fade_length.v">fade_length: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< Duration of the fade.</p>
|
|||
|
|
</div><span id="structfield.fade_level" class="structfield small-section-header"><a href="#structfield.fade_level" class="anchor field"></a><code id="fade_level.v">fade_level: <a class="type" href="../sdl2_sys/type.Uint16.html" title="type sdl2_sys::Uint16">Uint16</a></code></span><div class='docblock'><p>< Level at the end of the fade.</p>
|
|||
|
|
</div><h2 id='implementations' class='small-section-header'>Trait Implementations<a href='#implementations' class='anchor'></a></h2><div id='implementations-list'><h3 id='impl-Clone' class='impl'><code class='in-band'>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html" title="trait core::clone::Clone">Clone</a> for <a class="struct" href="../sdl2_sys/struct.SDL_HapticCustom.html" title="struct sdl2_sys::SDL_HapticCustom">SDL_HapticCustom</a></code><a href='#impl-Clone' class='anchor'></a><a class='srclink' href='../src/sdl2_sys/Users/travis/build/Rust-SDL2/rust-sdl2/target/debug/build/sdl2-sys-f32779682524d647/out/sdl_bindings.rs.html#14871' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.clone' class="method hidden"><code id='clone.v'>fn <a href='https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#tymethod.clone' class='fnname'>clone</a>(&self) -> <a class="struct" href="../sdl2_sys/struct.SDL_HapticCustom.html" title="struct sdl2_sys::SDL_HapticCustom">SDL_HapticCustom</a></code><a class='srclink' href='../src/sdl2_sys/Users/travis/build/Rust-SDL2/rust-sdl2/target/debug/build/sdl2-sys-f32779682524d647/out/sdl_bindings.rs.html#14871' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Returns a copy of the value. <a href="https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#tymethod.clone">Read more</a></p>
|
|||
|
|
</div><h4 id='method.clone_from' class="method hidden"><code id='clone_from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#method.clone_from' class='fnname'>clone_from</a>(&mut self, source: &Self)</code><span class='since' title='Stable since Rust version 1.0.0'>1.0.0</span><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/clone.rs.html#131-133' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs copy-assignment from <code>source</code>. <a href="https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#method.clone_from">Read more</a></p>
|
|||
|
|
</div></div><h3 id='impl-Copy' class='impl'><code class='in-band'>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Copy.html" title="trait core::marker::Copy">Copy</a> for <a class="struct" href="../sdl2_sys/struct.SDL_HapticCustom.html" title="struct sdl2_sys::SDL_HapticCustom">SDL_HapticCustom</a></code><a href='#impl-Copy' class='anchor'></a><a class='srclink' href='../src/sdl2_sys/Users/travis/build/Rust-SDL2/rust-sdl2/target/debug/build/sdl2-sys-f32779682524d647/out/sdl_bindings.rs.html#14871' title='goto source code'>[src]</a></h3><div class='impl-items'></div></div><h2 id='synthetic-implementations' class='small-section-header'>Auto Trait Implementations<a href='#synthetic-implementations' class='anchor'></a></h2><div id='synthetic-implementations-list'><h3 id='impl-Send' class='impl'><code class='in-band'>impl !<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Send.html" title="trait core::marker::Send">Send</a> for <a class="struct" href="../sdl2_sys/struct.SDL_HapticCustom.html" title="struct sdl2_sys::SDL_HapticCustom">SDL_HapticCustom</a></code><a href='#impl-Send' class='anchor'></a></h3><div class='impl-items'></div><h3 id='impl-Sync' class='impl'><code class='in-band'>impl !<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sync.html" title="trait core::marker::Sync">Sync</a> for <a class="struct" href="../sdl2_sys/struct.SDL_HapticCustom.html" title="struct sdl2_sys::SDL_HapticCustom">SDL_HapticCustom</a></code><a href='#impl-Sync' class='anchor'></a></h3><div class='impl-items'></div><h3 id='impl-Unpin' class='impl'><code class='in-band'>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Unpin.html" title="trait core::marker::Unpin">Unpin</a> for <a class="struct" href="../sdl2_sys/struct.SDL_HapticCustom.html" title="struct sdl2_sys::SDL_HapticCustom">SDL_HapticCustom</a></code><a href='#impl-Unpin' class='anchor'></a></h3><div class='impl-items'></div></div><h2 id='blanket-implementations' class='small-section-header'>Blanket Implementations<a href='#blanket-implementations' class='anchor'></a></h2><div id='blanket-implementations-list'><h3 id='impl-Any' class='impl'><code class='in-band'>impl<T> <a class="trait" href="https://doc.rust-lang.org/nightly/core/any/trait.Any.html" title="trait core::any::Any">Any</a> for T <span class="where fmt-newline">where<br> T: 'static + ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>, </span></code><a href='#impl-Any' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/any.rs.html#108-112' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.type_id' class="method hidden"><code id='type_id.v'>fn <a href='https://doc.rust-lang.org/nightly/core/any/trait.Any.html#tymethod.type_id' class='fnname'>type_id</a>(&self) -> <a class="struct" href="https://doc.rust-lang.org/nightly/core/any/struct.TypeId.html" title="struct core::any::TypeId">TypeId</a></code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/any.rs.html#109-111' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Gets the <code>TypeId</code> of <code>self</code>. <a href="https://doc.rust-lang.org/nightly/core/any/trait.Any.html#tymethod.type_id">Read more</a></p>
|
|||
|
|
</div></div><h3 id='impl-Borrow%3CT%3E' class='impl'><code class='in-band'>impl<T> <a class="trait" href="https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html" title="trait core::borrow::Borrow">Borrow</a><T> for T <span class="where fmt-newline">where<br> T: ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>, </span></code><a href='#impl-Borrow%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#213-217' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.borrow' class="method hidden"><code id='borrow.v'>fn <a href='https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html#tymethod.borrow' class='fnname'>borrow</a>(&self) -> &T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#214-216' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Immutably borrows from an owned value. <a href="https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html#tymethod.borrow">Read more</a></p>
|
|||
|
|
</div></div><h3 id='impl-BorrowMut%3CT%3E' class='impl'><code class='in-band'>impl<T> <a class="trait" href="https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html" title="trait core::borrow::BorrowMut">BorrowMut</a><T> for T <span class="where fmt-newline">where<br> T: ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>, </span></code><a href='#impl-BorrowMut%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#220-224' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.borrow_mut' class="method hidden"><code id='borrow_mut.v'>fn <a href='https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut' class='fnname'>borrow_mut</a>(&mut self) -> &mut T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#221-223' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Mutably borrows from an owned value. <a href="https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut">Read more</a></p>
|
|||
|
|
</div></div><h3 id='impl-From%3CT%3E' class='impl'><code class='in-band'>impl<T> <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.From.html" title="trait core::convert::From">From</a><T> for T</code><a href='#impl-From%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#565-569' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.from' class="method hidden"><code id='from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.From.html#tymethod.from' class='fnname'>from</a>(t: T) -> T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#566-568' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
|
|||
|
|
</div></div><h3 id='impl-Into%3CU%3E' class='impl'><code class='in-band'>impl<T, U> <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a><U> for T <span class="where fmt-newline">where<br> U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.From.html" title="trait core::convert::From">From</a><T>, </span></code><a href='#impl-Into%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#554-561' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.into' class="method hidden"><code id='into.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.Into.html#tymethod.into' class='fnname'>into</a>(self) -> U</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#558-560' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
|
|||
|
|
</div></div><h3 id='impl-TryFrom%3CU%3E' class='impl'><code class='in-band'>impl<T, U> <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><U> for T <span class="where fmt-newline">where<br> U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a><T>, </span></code><a href='#impl-TryFrom%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#602-611' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='associatedtype.Error' class="type"><code id='Error.t'>type <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error' class="type">Error</a> = <a class="enum" href="https://doc.rust-lang.org/nightly/core/convert/enum.Infallible.html" title="enum core::convert::Infallible">Infallible</a></code></h4><div class='docblock'><p>The type returned in the event of a conversion error.</p>
|
|||
|
|
</div><h4 id='method.try_from' class="method hidden"><code id='try_from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#tymethod.try_from' class='fnname'>try_from</a>(value: U) -> <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a><T, <T as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><U>>::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a>></code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#608-610' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
|
|||
|
|
</div></div><h3 id='impl-TryInto%3CU%3E' class='impl'><code class='in-band'>impl<T, U> <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html" title="trait core::convert::TryInto">TryInto</a><U> for T <span class="where fmt-newline">where<br> U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><T>, </span></code><a href='#impl-TryInto%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#588-597' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='associatedtype.Error-1' class="type"><code id='Error.t-1'>type <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html#associatedtype.Error' class="type">Error</a> = <U as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><T>>::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a></code></h4><div class='docblock'><p>The type returned in the event of a conversion error.</p>
|
|||
|
|
</div><h4 id='method.try_into' class="method hidden"><code id='try_into.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html#tymethod.try_into' class='fnname'>try_into</a>(self) -> <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a><U, <U as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><T>>::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a>></code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#594-596' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
|
|||
|
|
</div></div></div></section><section id="search" class="content hidden"></section><section class="footer"></section><script>window.rootPath = "../";window.currentCrate = "sdl2_sys";</script><script src="../aliases.js"></script><script src="../main.js"></script><script defer src="../search-index.js"></script></body></html>
|