Files

30 lines
25 KiB
HTML
Raw Permalink Normal View History

<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="API documentation for the Rust `XFontStruct` struct in crate `sdl2_sys`."><meta name="keywords" content="rust, rustlang, rust-lang, XFontStruct"><title>sdl2_sys::XFontStruct - Rust</title><link rel="stylesheet" type="text/css" href="../normalize.css"><link rel="stylesheet" type="text/css" href="../rustdoc.css" id="mainThemeStyle"><link rel="stylesheet" type="text/css" href="../dark.css"><link rel="stylesheet" type="text/css" href="../light.css" id="themeStyle"><script src="../storage.js"></script><noscript><link rel="stylesheet" href="../noscript.css"></noscript><link rel="shortcut icon" href="../favicon.ico"><style type="text/css">#crate-search{background-image:url("../down-arrow.svg");}</style></head><body class="rustdoc struct"><!--[if lte IE 8]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><nav class="sidebar"><div class="sidebar-menu">&#9776;</div><a href='../sdl2_sys/index.html'><div class='logo-container'><img src='../rust-logo.png' alt='logo'></div></a><p class='location'>Struct XFontStruct</p><div class="sidebar-elems"><div class="block items"><a class="sidebar-title" href="#fields">Fields</a><div class="sidebar-links"><a href="#structfield.ext_data">ext_data</a><a href="#structfield.fid">fid</a><a href="#structfield.direction">direction</a><a href="#structfield.min_char_or_byte2">min_char_or_byte2</a><a href="#structfield.max_char_or_byte2">max_char_or_byte2</a><a href="#structfield.min_byte1">min_byte1</a><a href="#structfield.max_byte1">max_byte1</a><a href="#structfield.all_chars_exist">all_chars_exist</a><a href="#structfield.default_char">default_char</a><a href="#structfield.n_properties">n_properties</a><a href="#structfield.properties">properties</a><a href="#structfield.min_bounds">min_bounds</a><a href="#structfield.max_bounds">max_bounds</a><a href="#structfield.per_char">per_char</a><a href="#structfield.ascent">ascent</a><a href="#structfield.descent">descent</a></div><a class="sidebar-title" href="#implementations">Trait Implementations</a><div class="sidebar-links"><a href="#impl-Clone">Clone</a><a href="#impl-Copy">Copy</a></div><a class="sidebar-title" href="#synthetic-implementations">Auto Trait Implementations</a><div class="sidebar-links"><a href="#impl-Send">!Send</a><a href="#impl-Sync">!Sync</a><a href="#impl-Unpin">Unpin</a></div><a class="sidebar-title" href="#blanket-implementations">Blanket Implementations</a><div class="sidebar-links"><a href="#impl-Any">Any</a><a href="#impl-Borrow%3CT%3E">Borrow&lt;T&gt;</a><a href="#impl-BorrowMut%3CT%3E">BorrowMut&lt;T&gt;</a><a href="#impl-From%3CT%3E">From&lt;T&gt;</a><a href="#impl-Into%3CU%3E">Into&lt;U&gt;</a><a href="#impl-TryFrom%3CU%3E">TryFrom&lt;U&gt;</a><a href="#impl-TryInto%3CU%3E">TryInto&lt;U&gt;</a></div></div><p class='location'><a href='index.html'>sdl2_sys</a></p><script>window.sidebarCurrent = {name: 'XFontStruct', ty: 'struct', relpath: ''};</script><script defer src="sidebar-items.js"></script></div></nav><div class="theme-picker"><button id="theme-picker" aria-label="Pick another theme!"><img src="../brush.svg" width="18" alt="Pick another theme!"></button><div id="theme-choices"></div></div><script src="../theme.js"></script><nav class="sub"><form class="search-form"><div class="search-container"><div><select id="crate-search"><option value="All crates">All crates</option></select><input class="search-input" name="search" disabled autocomplete="off" spellcheck="false" placeholder="Click or press S to search, ? for more options…" type="search"></div><a id="settings-menu" href="../settings.html"><img src="../wheel.svg" width="18" alt="Change settings"></a></div></form></nav><section id="main" class="content"><h1 class='fqn'><span class='out-of-band'><span id='render-detail'><a id="toggle-all-docs" href="javascript:void(0)" title="collapse all d
pub ext_data: *mut <a class="type" href="../sdl2_sys/type.XExtData.html" title="type sdl2_sys::XExtData">XExtData</a>,
pub fid: <a class="type" href="../sdl2_sys/type.Font.html" title="type sdl2_sys::Font">Font</a>,
pub direction: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a>,
pub min_char_or_byte2: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a>,
pub max_char_or_byte2: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a>,
pub min_byte1: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a>,
pub max_byte1: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a>,
pub all_chars_exist: <a class="type" href="../libc/unix/type.c_int.html" title="type libc::unix::c_int">c_int</a>,
pub default_char: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a>,
pub n_properties: <a class="type" href="../libc/unix/type.c_int.html" title="type libc::unix::c_int">c_int</a>,
pub properties: *mut <a class="struct" href="../sdl2_sys/struct.XFontProp.html" title="struct sdl2_sys::XFontProp">XFontProp</a>,
pub min_bounds: <a class="struct" href="../sdl2_sys/struct.XCharStruct.html" title="struct sdl2_sys::XCharStruct">XCharStruct</a>,
pub max_bounds: <a class="struct" href="../sdl2_sys/struct.XCharStruct.html" title="struct sdl2_sys::XCharStruct">XCharStruct</a>,
pub per_char: *mut <a class="struct" href="../sdl2_sys/struct.XCharStruct.html" title="struct sdl2_sys::XCharStruct">XCharStruct</a>,
pub ascent: <a class="type" href="../libc/unix/type.c_int.html" title="type libc::unix::c_int">c_int</a>,
pub descent: <a class="type" href="../libc/unix/type.c_int.html" title="type libc::unix::c_int">c_int</a>,
}</pre></div><h2 id='fields' class='fields small-section-header'>
Fields<a href='#fields' class='anchor'></a></h2><span id="structfield.ext_data" class="structfield small-section-header"><a href="#structfield.ext_data" class="anchor field"></a><code id="ext_data.v">ext_data: *mut <a class="type" href="../sdl2_sys/type.XExtData.html" title="type sdl2_sys::XExtData">XExtData</a></code></span><span id="structfield.fid" class="structfield small-section-header"><a href="#structfield.fid" class="anchor field"></a><code id="fid.v">fid: <a class="type" href="../sdl2_sys/type.Font.html" title="type sdl2_sys::Font">Font</a></code></span><span id="structfield.direction" class="structfield small-section-header"><a href="#structfield.direction" class="anchor field"></a><code id="direction.v">direction: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a></code></span><span id="structfield.min_char_or_byte2" class="structfield small-section-header"><a href="#structfield.min_char_or_byte2" class="anchor field"></a><code id="min_char_or_byte2.v">min_char_or_byte2: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a></code></span><span id="structfield.max_char_or_byte2" class="structfield small-section-header"><a href="#structfield.max_char_or_byte2" class="anchor field"></a><code id="max_char_or_byte2.v">max_char_or_byte2: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a></code></span><span id="structfield.min_byte1" class="structfield small-section-header"><a href="#structfield.min_byte1" class="anchor field"></a><code id="min_byte1.v">min_byte1: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a></code></span><span id="structfield.max_byte1" class="structfield small-section-header"><a href="#structfield.max_byte1" class="anchor field"></a><code id="max_byte1.v">max_byte1: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a></code></span><span id="structfield.all_chars_exist" class="structfield small-section-header"><a href="#structfield.all_chars_exist" class="anchor field"></a><code id="all_chars_exist.v">all_chars_exist: <a class="type" href="../libc/unix/type.c_int.html" title="type libc::unix::c_int">c_int</a></code></span><span id="structfield.default_char" class="structfield small-section-header"><a href="#structfield.default_char" class="anchor field"></a><code id="default_char.v">default_char: <a class="type" href="../libc/unix/type.c_uint.html" title="type libc::unix::c_uint">c_uint</a></code></span><span id="structfield.n_properties" class="structfield small-section-header"><a href="#structfield.n_properties" class="anchor field"></a><code id="n_properties.v">n_properties: <a class="type" href="../libc/unix/type.c_int.html" title="type libc::unix::c_int">c_int</a></code></span><span id="structfield.properties" class="structfield small-section-header"><a href="#structfield.properties" class="anchor field"></a><code id="properties.v">properties: *mut <a class="struct" href="../sdl2_sys/struct.XFontProp.html" title="struct sdl2_sys::XFontProp">XFontProp</a></code></span><span id="structfield.min_bounds" class="structfield small-section-header"><a href="#structfield.min_bounds" class="anchor field"></a><code id="min_bounds.v">min_bounds: <a class="struct" href="../sdl2_sys/struct.XCharStruct.html" title="struct sdl2_sys::XCharStruct">XCharStruct</a></code></span><span id="structfield.max_bounds" class="structfield small-section-header"><a href="#structfield.max_bounds" class="anchor field"></a><code id="max_bounds.v">max_bounds: <a class="struct" href="../sdl2_sys/struct.XCharStruct.html" title="struct sdl2_sys::XCharStruct">XCharStruct</a></code></span><span id="structfield.per_char" class="structfield small-section-header"><a href="#structfield.per_char" class="anchor field"></a><code id="per_char.v">per_char: *mut <a class="struct" href="../sdl2_sys/struct.XCharStruct.html" title="struct sdl2_sys::XCharStruct">XCharStruct</a></code></span><span id="str
</div><h4 id='method.clone_from' class="method hidden"><code id='clone_from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#method.clone_from' class='fnname'>clone_from</a>(&amp;mut self, source: &amp;Self)</code><span class='since' title='Stable since Rust version 1.0.0'>1.0.0</span><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/clone.rs.html#131-133' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs copy-assignment from <code>source</code>. <a href="https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#method.clone_from">Read more</a></p>
</div></div><h3 id='impl-Copy' class='impl'><code class='in-band'>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Copy.html" title="trait core::marker::Copy">Copy</a> for <a class="struct" href="../sdl2_sys/struct.XFontStruct.html" title="struct sdl2_sys::XFontStruct">XFontStruct</a></code><a href='#impl-Copy' class='anchor'></a><a class='srclink' href='../src/sdl2_sys/Users/travis/build/Rust-SDL2/rust-sdl2/target/debug/build/sdl2-sys-f32779682524d647/out/sdl_bindings.rs.html#25388' title='goto source code'>[src]</a></h3><div class='impl-items'></div></div><h2 id='synthetic-implementations' class='small-section-header'>Auto Trait Implementations<a href='#synthetic-implementations' class='anchor'></a></h2><div id='synthetic-implementations-list'><h3 id='impl-Send' class='impl'><code class='in-band'>impl !<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Send.html" title="trait core::marker::Send">Send</a> for <a class="struct" href="../sdl2_sys/struct.XFontStruct.html" title="struct sdl2_sys::XFontStruct">XFontStruct</a></code><a href='#impl-Send' class='anchor'></a></h3><div class='impl-items'></div><h3 id='impl-Sync' class='impl'><code class='in-band'>impl !<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sync.html" title="trait core::marker::Sync">Sync</a> for <a class="struct" href="../sdl2_sys/struct.XFontStruct.html" title="struct sdl2_sys::XFontStruct">XFontStruct</a></code><a href='#impl-Sync' class='anchor'></a></h3><div class='impl-items'></div><h3 id='impl-Unpin' class='impl'><code class='in-band'>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Unpin.html" title="trait core::marker::Unpin">Unpin</a> for <a class="struct" href="../sdl2_sys/struct.XFontStruct.html" title="struct sdl2_sys::XFontStruct">XFontStruct</a></code><a href='#impl-Unpin' class='anchor'></a></h3><div class='impl-items'></div></div><h2 id='blanket-implementations' class='small-section-header'>Blanket Implementations<a href='#blanket-implementations' class='anchor'></a></h2><div id='blanket-implementations-list'><h3 id='impl-Any' class='impl'><code class='in-band'>impl&lt;T&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/any/trait.Any.html" title="trait core::any::Any">Any</a> for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;T: 'static + ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>,&nbsp;</span></code><a href='#impl-Any' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/any.rs.html#108-112' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.type_id' class="method hidden"><code id='type_id.v'>fn <a href='https://doc.rust-lang.org/nightly/core/any/trait.Any.html#tymethod.type_id' class='fnname'>type_id</a>(&amp;self) -&gt; <a class="struct" href="https://doc.rust-lang.org/nightly/core/any/struct.TypeId.html" title="struct core::any::TypeId">TypeId</a></code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/any.rs.html#109-111' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Gets the <code>TypeId</code> of <code>self</code>. <a href="https://doc.rust-lang.org/nightly/core/any/trait.Any.html#tymethod.type_id">Read more</a></p>
</div></div><h3 id='impl-Borrow%3CT%3E' class='impl'><code class='in-band'>impl&lt;T&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html" title="trait core::borrow::Borrow">Borrow</a>&lt;T&gt; for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;T: ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>,&nbsp;</span></code><a href='#impl-Borrow%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#213-217' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.borrow' class="method hidden"><code id='borrow.v'>fn <a href='https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html#tymethod.borrow' class='fnname'>borrow</a>(&amp;self) -&gt; &amp;T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#214-216' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Immutably borrows from an owned value. <a href="https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html#tymethod.borrow">Read more</a></p>
</div></div><h3 id='impl-BorrowMut%3CT%3E' class='impl'><code class='in-band'>impl&lt;T&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html" title="trait core::borrow::BorrowMut">BorrowMut</a>&lt;T&gt; for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;T: ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>,&nbsp;</span></code><a href='#impl-BorrowMut%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#220-224' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.borrow_mut' class="method hidden"><code id='borrow_mut.v'>fn <a href='https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut' class='fnname'>borrow_mut</a>(&amp;mut self) -&gt; &amp;mut T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#221-223' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Mutably borrows from an owned value. <a href="https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut">Read more</a></p>
</div></div><h3 id='impl-From%3CT%3E' class='impl'><code class='in-band'>impl&lt;T&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.From.html" title="trait core::convert::From">From</a>&lt;T&gt; for T</code><a href='#impl-From%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#565-569' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.from' class="method hidden"><code id='from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.From.html#tymethod.from' class='fnname'>from</a>(t: T) -&gt; T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#566-568' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
</div></div><h3 id='impl-Into%3CU%3E' class='impl'><code class='in-band'>impl&lt;T, U&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a>&lt;U&gt; for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.From.html" title="trait core::convert::From">From</a>&lt;T&gt;,&nbsp;</span></code><a href='#impl-Into%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#554-561' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.into' class="method hidden"><code id='into.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.Into.html#tymethod.into' class='fnname'>into</a>(self) -&gt; U</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#558-560' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
</div></div><h3 id='impl-TryFrom%3CU%3E' class='impl'><code class='in-band'>impl&lt;T, U&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a>&lt;U&gt; for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a>&lt;T&gt;,&nbsp;</span></code><a href='#impl-TryFrom%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#602-611' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='associatedtype.Error' class="type"><code id='Error.t'>type <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error' class="type">Error</a> = <a class="enum" href="https://doc.rust-lang.org/nightly/core/convert/enum.Infallible.html" title="enum core::convert::Infallible">Infallible</a></code></h4><div class='docblock'><p>The type returned in the event of a conversion error.</p>
</div><h4 id='method.try_from' class="method hidden"><code id='try_from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#tymethod.try_from' class='fnname'>try_from</a>(value: U) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;T, &lt;T as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a>&lt;U&gt;&gt;::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a>&gt;</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#608-610' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
</div></div><h3 id='impl-TryInto%3CU%3E' class='impl'><code class='in-band'>impl&lt;T, U&gt; <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html" title="trait core::convert::TryInto">TryInto</a>&lt;U&gt; for T <span class="where fmt-newline">where<br>&nbsp;&nbsp;&nbsp;&nbsp;U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a>&lt;T&gt;,&nbsp;</span></code><a href='#impl-TryInto%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#588-597' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='associatedtype.Error-1' class="type"><code id='Error.t-1'>type <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html#associatedtype.Error' class="type">Error</a> = &lt;U as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a>&lt;T&gt;&gt;::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a></code></h4><div class='docblock'><p>The type returned in the event of a conversion error.</p>
</div><h4 id='method.try_into' class="method hidden"><code id='try_into.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html#tymethod.try_into' class='fnname'>try_into</a>(self) -&gt; <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a>&lt;U, &lt;U as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a>&lt;T&gt;&gt;::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a>&gt;</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#594-596' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
</div></div></div></section><section id="search" class="content hidden"></section><section class="footer"></section><script>window.rootPath = "../";window.currentCrate = "sdl2_sys";</script><script src="../aliases.js"></script><script src="../main.js"></script><script defer src="../search-index.js"></script></body></html>